@@ -49,15 +49,9 @@ impl MidiChannel {
     fn ensure_sorted(&mut self) -> bool {
         if self.need_sort {
             dmsort::sort_by(&mut self.messages, |a, b| {
-                let units_a = a.effect_units().0;
-                let units_b = b.effect_units().0;
-                if units_a == units_b {
-                    Ordering::Equal
-                } else if units_a < units_b {
-                    Ordering::Less
-                } else {
-                    Ordering::Greater
-                }
+                let units_a = a.effect_units();
+                let units_b = b.effect_units();
+                units_a.cmp(&units_b)
             });
             self.need_sort = false;
             true
@@ -157,7 +151,9 @@ impl MidiChannel {
                     self.next_index += 1;
                     count += 1;
                     if !bypass {
-                        hub.send(settings, speed, next, velocity);
+                        if !is_seeking || next.should_send_in_seeking() {
+                            hub.send(settings, speed, next, velocity);
+                        }
                     }
                 } else {
                     if next.effect_position().bar_ordinal < play_control.begin_bar_ordinal {
